@@ -11,9 +11,6 @@ from broqer.op.bitwise import BitwiseCombineLatest, map_bit
 from broqer.op.cache import Cache
 from broqer.op.throttle import Throttle
 
-# utils
-from broqer.op.concat import Concat
-
 # enable operator overloading
 from .py_operators import Str, Bool, Int, Float, Repr, Len, In, All, Any, \
                          BitwiseAnd, BitwiseOr, Not
@@ -22,7 +19,7 @@ __all__ = [
     'CombineLatest', 'BitwiseCombineLatest',
     'Filter', 'Map', 'EvalTrue', 'MapAsync', 'build_map_async', 'AsyncMode',
     'EvalFalse', 'build_map', 'build_map_factory', 'build_combine_latest',
-    'build_filter', 'build_filter_factory', 'Concat', 'Str', 'Bool', 'Int',
+    'build_filter', 'build_filter_factory', 'Str', 'Bool', 'Int',
     'Float', 'Repr', 'map_bit', 'build_map_async_factory',
     'Len', 'In', 'All', 'Any', 'BitwiseAnd', 'BitwiseOr', 'Not', 'Throttle',
     'Cache'
