@@ -32,21 +32,24 @@ Using the initial value for cache:
 from typing import Any
 
 from broqer import Publisher, NONE
-from broqer.publisher import TValue
-from broqer.operator import Operator, OperatorFactory
+from broqer.publisher import ValueT
+from broqer.operator import Operator
 
 
-class AppliedCache(Operator):
+class Cache(Operator):
     """ Cache object applied to publisher (see Map) """
-    def __init__(self, publisher: Publisher, init: Any = NONE) -> None:
-        Operator.__init__(self, publisher)
+    def __init__(self, init: Any = NONE) -> None:
+        Operator.__init__(self)
         self._state = init
 
-    def get(self) -> TValue:
-        return self._orginator.get()
+    def get(self) -> ValueT:
+        if self._originator is None:
+            raise ValueError('Operator is missing originator')
 
-    def emit(self, value: TValue, who: Publisher) -> None:
-        if who is not self._orginator:
+        return self._originator.get()
+
+    def emit(self, value: ValueT, who: Publisher) -> None:
+        if who is not self._originator:
             raise ValueError('Emit from non assigned publisher')
 
         if value != self._state:
@@ -54,15 +57,3 @@ class AppliedCache(Operator):
             return Publisher.notify(self, value)
 
         return None
-
-
-class Cache(OperatorFactory):  # pylint: disable=too-few-public-methods
-    """ Cache emitted values. Suppress duplicated value emits.
-
-    :param init: optional initialization state
-    """
-    def __init__(self, init: Any = NONE) -> None:
-        self._init = init
-
-    def apply(self, publisher: Publisher):
-        return AppliedCache(publisher, self._init)
